@@ -21,6 +21,7 @@ from oslo_log import log as logging
 from oslo_serialization import jsonutils as json
 from oslo_utils import encodeutils
 import six
+from six.moves import http_client as http
 import six.moves.urllib.parse as urlparse
 import webob.exc
 
@@ -274,12 +275,15 @@ class ImagesController(object):
                     "invisible.")
             raise webob.exc.HTTPForbidden(explanation=msg)
 
+        if image.status not in ('active', 'queued'):
+            msg = _("It's not allowed to replace locations if image status is "
+                    "%s.") % image.status
+            raise webob.exc.HTTPConflict(explanation=msg)
+
         try:
             # NOTE(flwang): _locations_proxy's setattr method will check if
             # the update is acceptable.
             image.locations = value
-            if image.status == 'queued':
-                image.status = 'active'
         except (exception.BadStoreUri, exception.DuplicateLocation) as e:
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
         except ValueError as ve:    # update image status failed.
@@ -292,6 +296,11 @@ class ImagesController(object):
                     "invisible.")
             raise webob.exc.HTTPForbidden(explanation=msg)
 
+        if image.status not in ('active', 'queued'):
+            msg = _("It's not allowed to add locations if image status is "
+                    "%s.") % image.status
+            raise webob.exc.HTTPConflict(explanation=msg)
+
         pos = self._get_locations_op_pos(path_pos,
                                          len(image.locations), True)
         if pos is None:
@@ -313,6 +322,11 @@ class ImagesController(object):
                     "invisible.")
             raise webob.exc.HTTPForbidden(explanation=msg)
 
+        if image.status not in ('active'):
+            msg = _("It's not allowed to remove locations if image status is "
+                    "%s.") % image.status
+            raise webob.exc.HTTPConflict(explanation=msg)
+
         if len(image.locations) == 1:
             LOG.debug("User forbidden to remove last location of image %s",
                       image.image_id)
@@ -500,13 +514,13 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
             partial_image = {path_root: change['value']}
         elif ((path_root in get_base_properties().keys()) and
               (get_base_properties()[path_root].get('type', '') == 'array')):
-            # NOTE(zhiyan): cient can use PATCH API to adding element to
-            # the image's existing set property directly.
-            # Such as: 1. using '/locations/N' path to adding a location
-            #             to the image's 'locations' list at N position.
+            # NOTE(zhiyan): client can use the PATCH API to add an element
+            # directly to an existing property
+            # Such as: 1. using '/locations/N' path to add a location
+            #             to the image's 'locations' list at position N.
             #             (implemented)
-            #          2. using '/tags/-' path to appending a tag to the
-            #             image's 'tags' list at last. (Not implemented)
+            #          2. using '/tags/-' path to append a tag to the
+            #             image's 'tags' list at the end. (Not implemented)
             partial_image = {path_root: [change['value']]}
 
         if partial_image:
@@ -618,7 +632,7 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
     def _get_filters(self, filters):
         visibility = filters.get('visibility')
         if visibility:
-            if visibility not in ['public', 'private', 'shared']:
+            if visibility not in ['community', 'public', 'private', 'shared']:
                 msg = _('Invalid visibility value: %s') % visibility
                 raise webob.exc.HTTPBadRequest(explanation=msg)
         changes_since = filters.get('changes-since', None)
@@ -790,7 +804,7 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
             raise webob.exc.HTTPForbidden(explanation=e.msg)
 
     def create(self, response, image):
-        response.status_int = 201
+        response.status_int = http.CREATED
         self.show(response, image)
         response.location = self._get_image_href(image)
 
@@ -826,7 +840,7 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
         response.content_type = 'application/json'
 
     def delete(self, response, result):
-        response.status_int = 204
+        response.status_int = http.NO_CONTENT
 
 
 def get_base_properties():
@@ -852,7 +866,7 @@ def get_base_properties():
         'visibility': {
             'type': 'string',
             'description': _('Scope of image accessibility'),
-            'enum': ['public', 'private'],
+            'enum': ['community', 'public', 'private', 'shared'],
         },
         'protected': {
             'type': 'boolean',
