@@ -18,6 +18,7 @@ from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
 import six
+from six.moves import http_client as http
 import six.moves.urllib.parse as urlparse
 import webob.exc
 from wsme.rest import json
@@ -35,13 +36,11 @@ from glance.common import wsgi
 from glance.common import wsme_utils
 import glance.db
 import glance.gateway
-from glance import i18n
+from glance.i18n import _, _LE
 import glance.notifier
 import glance.schema
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LE = i18n._LE
 
 CONF = cfg.CONF
 
@@ -164,7 +163,10 @@ class NamespaceController(object):
                             **self._to_property_dict(name, value)
                         ))
                     prop_repo.add(new_property_type)
-
+        except exception.Invalid as e:
+            msg = (_("Couldn't create metadata namespace: %s")
+                   % encodeutils.exception_to_unicode(e))
+            raise webob.exc.HTTPBadRequest(explanation=msg)
         except exception.Forbidden as e:
             self._cleanup_namespace(ns_repo, namespace, namespace_created)
             LOG.debug("User not permitted to create metadata namespace")
@@ -202,9 +204,8 @@ class NamespaceController(object):
                 namespace_obj = namespace_repo.get(namespace.namespace)
                 namespace_obj.delete()
                 namespace_repo.remove(namespace_obj)
-                msg = ("Cleaned up namespace %(namespace)s "
-                       % {'namespace': namespace.namespace})
-                LOG.debug(msg)
+                LOG.debug("Cleaned up namespace %(namespace)s ",
+                          {'namespace': namespace.namespace})
             except exception:
                 msg = (_LE("Failed to delete namespace %(namespace)s ") %
                        {'namespace': namespace.namespace})
@@ -288,6 +289,10 @@ class NamespaceController(object):
             ns_obj.owner = (
                 wsme_utils._get_value(user_ns.owner) or req.context.owner)
             updated_namespace = namespace_repo.save(ns_obj)
+        except exception.Invalid as e:
+            msg = (_("Couldn't update metadata namespace: %s")
+                   % encodeutils.exception_to_unicode(e))
+            raise webob.exc.HTTPBadRequest(explanation=msg)
         except exception.Forbidden as e:
             LOG.debug("User not permitted to update metadata namespace "
                       "'%s'", namespace)
@@ -506,7 +511,7 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
 
     def create(self, response, namespace):
         ns_json = json.tojson(Namespace, namespace)
-        response = self.__render(ns_json, response, 201)
+        response = self.__render(ns_json, response, http.CREATED)
         response.location = get_namespace_href(namespace)
 
     def show(self, response, namespace):
@@ -531,16 +536,16 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
 
     def update(self, response, namespace):
         ns_json = json.tojson(Namespace, namespace)
-        response = self.__render(ns_json, response, 200)
+        response = self.__render(ns_json, response, http.OK)
 
     def delete(self, response, result):
-        response.status_int = 204
+        response.status_int = http.NO_CONTENT
 
     def delete_objects(self, response, result):
-        response.status_int = 204
+        response.status_int = http.NO_CONTENT
 
     def delete_properties(self, response, result):
-        response.status_int = 204
+        response.status_int = http.NO_CONTENT
 
     def __render(self, json_data, response, response_status=None):
         body = jsonutils.dumps(json_data, ensure_ascii=False)
@@ -580,7 +585,8 @@ def get_schema_definitions():
                 "required": ["title", "type"],
                 "properties": {
                     "name": {
-                        "type": "string"
+                        "type": "string",
+                        "maxLength": 255
                     },
                     "title": {
                         "type": "string"
@@ -706,20 +712,23 @@ def _get_base_properties():
         },
         "created_at": {
             "type": "string",
-            "description": _("Date and time of namespace creation"
-                             " (READ-ONLY)"),
+            "readOnly": True,
+            "description": _("Date and time of namespace creation"),
             "format": "date-time"
         },
         "updated_at": {
             "type": "string",
-            "description": _("Date and time of the last namespace modification"
-                             " (READ-ONLY)"),
+            "readOnly": True,
+            "description": _("Date and time of the last namespace"
+                             " modification"),
             "format": "date-time"
         },
         "schema": {
+            'readOnly': True,
             "type": "string"
         },
         "self": {
+            'readOnly': True,
             "type": "string"
         },
         "resource_type_associations": {
