@@ -31,15 +31,10 @@ database back-end.
 
 import functools
 
-from oslo_log import log as logging
-
-from glance import artifacts
+from glance import glare
 from glance.registry.client.v2 import api
 
 
-LOG = logging.getLogger(__name__)
-
-
 def configure():
     api.configure_registry_client()
 
@@ -59,13 +54,14 @@ def _get_client(func):
 
 
 @_get_client
-def image_create(client, values):
+def image_create(client, values, v1_mode=False):
     """Create an image from the values dictionary."""
-    return client.image_create(values=values)
+    return client.image_create(values=values, v1_mode=v1_mode)
 
 
 @_get_client
-def image_update(client, image_id, values, purge_props=False, from_state=None):
+def image_update(client, image_id, values, purge_props=False, from_state=None,
+                 v1_mode=False):
     """
     Set the given properties on an image and update it.
 
@@ -73,7 +69,9 @@ def image_update(client, image_id, values, purge_props=False, from_state=None):
     """
     return client.image_update(values=values,
                                image_id=image_id,
-                               purge_props=purge_props, from_state=from_state)
+                               purge_props=purge_props,
+                               from_state=from_state,
+                               v1_mode=v1_mode)
 
 
 @_get_client
@@ -83,9 +81,10 @@ def image_destroy(client, image_id):
 
 
 @_get_client
-def image_get(client, image_id, force_show_deleted=False):
+def image_get(client, image_id, force_show_deleted=False, v1_mode=False):
     return client.image_get(image_id=image_id,
-                            force_show_deleted=force_show_deleted)
+                            force_show_deleted=force_show_deleted,
+                            v1_mode=v1_mode)
 
 
 def is_image_visible(context, image, status=None):
@@ -98,8 +97,8 @@ def is_image_visible(context, image, status=None):
     if image['owner'] is None:
         return True
 
-    # Image is_public == image visible
-    if image['is_public']:
+    # Public or Community visibility == image visible
+    if image['visibility'] in ['public', 'community']:
         return True
 
     # Perform tests based on whether we have an owner
@@ -107,13 +106,14 @@ def is_image_visible(context, image, status=None):
         if context.owner == image['owner']:
             return True
 
-        # Figure out if this image is shared with that tenant
-        members = image_member_find(context,
-                                    image_id=image['id'],
-                                    member=context.owner,
-                                    status=status)
-        if members:
-            return True
+        if 'shared' == image['visibility']:
+            # Figure out if this image is shared with that tenant
+            members = image_member_find(context,
+                                        image_id=image['id'],
+                                        member=context.owner,
+                                        status=status)
+            if members:
+                return True
 
     # Private image
     return False
@@ -123,7 +123,7 @@ def is_image_visible(context, image, status=None):
 def image_get_all(client, filters=None, marker=None, limit=None,
                   sort_key=None, sort_dir=None,
                   member_status='accepted', is_public=None,
-                  admin_as_user=False, return_tag=False):
+                  admin_as_user=False, return_tag=False, v1_mode=False):
     """
     Get all images that match zero or more filters.
 
@@ -144,6 +144,8 @@ def image_get_all(client, filters=None, marker=None, limit=None,
     :param return_tag: To indicates whether image entry in result includes it
                        relevant tag entries. This could improve upper-layer
                        query performance, to prevent using separated calls
+    :param v1_mode: If true, mutates the 'visibility' value of each image
+                    into the v1-compatible field 'is_public'
     """
     sort_key = ['created_at'] if not sort_key else sort_key
     sort_dir = ['desc'] if not sort_dir else sort_dir
@@ -152,7 +154,8 @@ def image_get_all(client, filters=None, marker=None, limit=None,
                                 member_status=member_status,
                                 is_public=is_public,
                                 admin_as_user=admin_as_user,
-                                return_tag=return_tag)
+                                return_tag=return_tag,
+                                v1_mode=v1_mode)
 
 
 @_get_client
@@ -261,7 +264,7 @@ def user_get_storage_usage(client, owner_id, image_id=None, session=None):
 @_get_client
 def task_get(client, task_id, session=None, force_show_deleted=False):
     """Get a single task object
-    :return: task dictionary
+    :returns: task dictionary
     """
     return client.task_get(task_id=task_id, session=session,
                            force_show_deleted=force_show_deleted)
@@ -280,7 +283,7 @@ def task_get_all(client, filters=None, marker=None, limit=None,
     :param admin_as_user: For backwards compatibility. If true, then return to
                       an admin the equivalent set of tasks which it would see
                       if it were a regular user
-    :return: tasks set
+    :returns: tasks set
     """
     return client.task_get_all(filters=filters, marker=marker, limit=limit,
                                sort_key=sort_key, sort_dir=sort_dir,
@@ -604,8 +607,10 @@ def artifact_get(client, artifact_id,
 
 @_get_client
 def artifact_get_all(client, marker=None, limit=None, sort_key=None,
-                     sort_dir=None, filters={},
-                     show_level=artifacts.Showlevel.NONE, session=None):
+                     sort_dir=None, filters=None,
+                     show_level=glare.Showlevel.NONE, session=None):
+    if filters is None:
+        filters = {}
     return client.artifact_create(marker, limit, sort_key,
                                   sort_dir, filters, show_level)
 
