@@ -119,7 +119,7 @@ class Controller(object):
             del params['is_public']
         try:
             return self.db_api.image_get_all(context, filters=filters,
-                                             **params)
+                                             v1_mode=True, **params)
         except exception.ImageNotFound:
             LOG.warn(_LW("Invalid marker. Image %(id)s could not be "
                          "found.") % {'id': params.get('marker')})
@@ -138,20 +138,25 @@ class Controller(object):
         """Return a basic filtered list of public, non-deleted images
 
         :param req: the Request object coming from the wsgi layer
-        :retval a mapping of the following form::
+        :returns: a mapping of the following form
+
+        .. code-block:: python
 
             dict(images=[image_list])
 
-        Where image_list is a sequence of mappings::
+        Where image_list is a sequence of mappings
+
+        .. code-block:: json
 
             {
-            'id': <ID>,
-            'name': <NAME>,
-            'size': <SIZE>,
-            'disk_format': <DISK_FORMAT>,
-            'container_format': <CONTAINER_FORMAT>,
-            'checksum': <CHECKSUM>
+                'id': <ID>,
+                'name': <NAME>,
+                'size': <SIZE>,
+                'disk_format': <DISK_FORMAT>,
+                'container_format': <CONTAINER_FORMAT>,
+                'checksum': <CHECKSUM>
             }
+
         """
         params = self._get_query_params(req)
         images = self._get_images(req.context, **params)
@@ -170,12 +175,29 @@ class Controller(object):
         """Return a filtered list of public, non-deleted images in detail
 
         :param req: the Request object coming from the wsgi layer
-        :retval a mapping of the following form::
+        :returns: a mapping of the following form
 
-            dict(images=[image_list])
+        .. code-block:: json
+
+            {'images':
+                [{
+                    'id': <ID>,
+                    'name': <NAME>,
+                    'size': <SIZE>,
+                    'disk_format': <DISK_FORMAT>,
+                    'container_format': <CONTAINER_FORMAT>,
+                    'checksum': <CHECKSUM>,
+                    'min_disk': <MIN_DISK>,
+                    'min_ram': <MIN_RAM>,
+                    'store': <STORE>,
+                    'status': <STATUS>,
+                    'created_at': <TIMESTAMP>,
+                    'updated_at': <TIMESTAMP>,
+                    'deleted_at': <TIMESTAMP>|<NONE>,
+                    'properties': {'distro': 'Ubuntu 10.04 LTS', {...}}
+                }, {...}]
+            }
 
-        Where image_list is a sequence of mappings containing
-        all image model fields.
         """
         params = self._get_query_params(req)
 
@@ -188,7 +210,7 @@ class Controller(object):
         """Extract necessary query parameters from http request.
 
         :param req: the Request object coming from the wsgi layer
-        :retval dictionary of filters to apply to list of images
+        :returns: dictionary of filters to apply to list of images
         """
         params = {
             'filters': self._get_filters(req),
@@ -217,7 +239,7 @@ class Controller(object):
         """Return a dictionary of query param filters from the request
 
         :param req: the Request object coming from the wsgi layer
-        :retval a dict of key/value filters
+        :returns: a dict of key/value filters
         """
         filters = {}
         properties = {}
@@ -336,7 +358,7 @@ class Controller(object):
     def show(self, req, id):
         """Return data about the given image id."""
         try:
-            image = self.db_api.image_get(req.context, id)
+            image = self.db_api.image_get(req.context, id, v1_mode=True)
             LOG.debug("Successfully retrieved image %(id)s", {'id': id})
         except exception.ImageNotFound:
             LOG.info(_LI("Image %(id)s not found"), {'id': id})
@@ -360,8 +382,9 @@ class Controller(object):
         :param req: wsgi Request object
         :param id:  The opaque internal identifier for the image
 
-        :retval Returns 200 if delete was successful, a fault if not. On
-        success, the body contains the deleted image information as a mapping.
+        :returns: 200 if delete was successful, a fault if not. On
+            success, the body contains the deleted image
+            information as a mapping.
         """
         try:
             deleted_image = self.db_api.image_destroy(req.context, id)
@@ -390,9 +413,9 @@ class Controller(object):
         :param req: wsgi Request object
         :param body: Dictionary of information about the image
 
-        :retval Returns the newly-created image information as a mapping,
-                which will include the newly-created image's internal id
-                in the 'id' field
+        :returns: The newly-created image information as a mapping,
+            which will include the newly-created image's internal id
+            in the 'id' field
         """
         image_data = body['image']
 
@@ -415,7 +438,8 @@ class Controller(object):
 
         try:
             image_data = _normalize_image_location_for_db(image_data)
-            image_data = self.db_api.image_create(req.context, image_data)
+            image_data = self.db_api.image_create(req.context, image_data,
+                                                  v1_mode=True)
             image_data = dict(image=make_image_dict(image_data))
             LOG.info(_LI("Successfully created image %(id)s"),
                      {'id': image_data['image']['id']})
@@ -441,7 +465,7 @@ class Controller(object):
         :param body: Dictionary of information about the image
         :param id:  The opaque internal identifier for the image
 
-        :retval Returns the updated image information as a mapping,
+        :returns: Returns the updated image information as a mapping,
         """
         image_data = body['image']
         from_state = body.get('from_state', None)
@@ -471,7 +495,8 @@ class Controller(object):
             updated_image = self.db_api.image_update(req.context, id,
                                                      image_data,
                                                      purge_props=purge_props,
-                                                     from_state=from_state)
+                                                     from_state=from_state,
+                                                     v1_mode=True)
 
             LOG.info(_LI("Updating metadata for image %(id)s"), {'id': id})
             return dict(image=make_image_dict(updated_image))
