@@ -18,6 +18,7 @@
 
 import httplib2
 from oslo_serialization import jsonutils
+from six.moves import http_client
 
 from glance.tests import functional
 
@@ -32,10 +33,20 @@ class TestApiVersions(functional.FunctionalTest):
         url = 'http://127.0.0.1:%d/v%%s/' % self.api_port
         versions = {'versions': [
             {
-                'id': 'v2.3',
+                'id': 'v2.5',
                 'status': 'CURRENT',
                 'links': [{'rel': 'self', 'href': url % '2'}],
             },
+            {
+                'id': 'v2.4',
+                'status': 'SUPPORTED',
+                'links': [{'rel': 'self', 'href': url % '2'}],
+            },
+            {
+                'id': 'v2.3',
+                'status': 'SUPPORTED',
+                'links': [{'rel': 'self', 'href': url % '2'}],
+            },
             {
                 'id': 'v2.2',
                 'status': 'SUPPORTED',
@@ -53,12 +64,12 @@ class TestApiVersions(functional.FunctionalTest):
             },
             {
                 'id': 'v1.1',
-                'status': 'SUPPORTED',
+                'status': 'DEPRECATED',
                 'links': [{'rel': 'self', 'href': url % '1'}],
             },
             {
                 'id': 'v1.0',
-                'status': 'SUPPORTED',
+                'status': 'DEPRECATED',
                 'links': [{'rel': 'self', 'href': url % '1'}],
             },
         ]}
@@ -68,7 +79,7 @@ class TestApiVersions(functional.FunctionalTest):
         path = 'http://%s:%d' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
         self.assertEqual(versions_json, content)
 
     def test_v2_api_configuration(self):
@@ -79,10 +90,20 @@ class TestApiVersions(functional.FunctionalTest):
         url = 'http://127.0.0.1:%d/v%%s/' % self.api_port
         versions = {'versions': [
             {
-                'id': 'v2.3',
+                'id': 'v2.5',
                 'status': 'CURRENT',
                 'links': [{'rel': 'self', 'href': url % '2'}],
             },
+            {
+                'id': 'v2.4',
+                'status': 'SUPPORTED',
+                'links': [{'rel': 'self', 'href': url % '2'}],
+            },
+            {
+                'id': 'v2.3',
+                'status': 'SUPPORTED',
+                'links': [{'rel': 'self', 'href': url % '2'}],
+            },
             {
                 'id': 'v2.2',
                 'status': 'SUPPORTED',
@@ -105,7 +126,7 @@ class TestApiVersions(functional.FunctionalTest):
         path = 'http://%s:%d' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
         self.assertEqual(versions_json, content)
 
     def test_v1_api_configuration(self):
@@ -117,12 +138,12 @@ class TestApiVersions(functional.FunctionalTest):
         versions = {'versions': [
             {
                 'id': 'v1.1',
-                'status': 'SUPPORTED',
+                'status': 'DEPRECATED',
                 'links': [{'rel': 'self', 'href': url % '1'}],
             },
             {
                 'id': 'v1.0',
-                'status': 'SUPPORTED',
+                'status': 'DEPRECATED',
                 'links': [{'rel': 'self', 'href': url % '1'}],
             },
         ]}
@@ -132,7 +153,7 @@ class TestApiVersions(functional.FunctionalTest):
         path = 'http://%s:%d' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
         self.assertEqual(versions_json, content)
 
 
@@ -144,10 +165,20 @@ class TestApiPaths(functional.FunctionalTest):
         url = 'http://127.0.0.1:%d/v%%s/' % self.api_port
         versions = {'versions': [
             {
-                'id': 'v2.3',
+                'id': 'v2.5',
                 'status': 'CURRENT',
                 'links': [{'rel': 'self', 'href': url % '2'}],
             },
+            {
+                'id': 'v2.4',
+                'status': 'SUPPORTED',
+                'links': [{'rel': 'self', 'href': url % '2'}],
+            },
+            {
+                'id': 'v2.3',
+                'status': 'SUPPORTED',
+                'links': [{'rel': 'self', 'href': url % '2'}],
+            },
             {
                 'id': 'v2.2',
                 'status': 'SUPPORTED',
@@ -165,12 +196,12 @@ class TestApiPaths(functional.FunctionalTest):
             },
             {
                 'id': 'v1.1',
-                'status': 'SUPPORTED',
+                'status': 'DEPRECATED',
                 'links': [{'rel': 'self', 'href': url % '1'}],
             },
             {
                 'id': 'v1.0',
-                'status': 'SUPPORTED',
+                'status': 'DEPRECATED',
                 'links': [{'rel': 'self', 'href': url % '1'}],
             },
         ]}
@@ -186,7 +217,7 @@ class TestApiPaths(functional.FunctionalTest):
         path = 'http://%s:%d' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
         self.assertEqual(self.versions_json, content)
 
     def test_get_images_path(self):
@@ -196,7 +227,7 @@ class TestApiPaths(functional.FunctionalTest):
         path = 'http://%s:%d/images' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
         self.assertEqual(self.versions_json, content)
 
     def test_get_v1_images_path(self):
@@ -206,7 +237,7 @@ class TestApiPaths(functional.FunctionalTest):
         path = 'http://%s:%d/v1/images' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
     def test_get_root_path_with_unknown_header(self):
         """Assert GET / with Accept: unknown header
@@ -217,7 +248,7 @@ class TestApiPaths(functional.FunctionalTest):
         http = httplib2.Http()
         headers = {'Accept': 'unknown'}
         response, content = http.request(path, 'GET', headers=headers)
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
         self.assertEqual(self.versions_json, content)
 
     def test_get_root_path_with_openstack_header(self):
@@ -228,7 +259,7 @@ class TestApiPaths(functional.FunctionalTest):
         http = httplib2.Http()
         headers = {'Accept': 'application/vnd.openstack.images-v1'}
         response, content = http.request(path, 'GET', headers=headers)
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual(self.images_json, content)
 
     def test_get_images_path_with_openstack_header(self):
@@ -241,7 +272,7 @@ class TestApiPaths(functional.FunctionalTest):
         http = httplib2.Http()
         headers = {'Accept': 'application/vnd.openstack.compute-v1'}
         response, content = http.request(path, 'GET', headers=headers)
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
         self.assertEqual(self.versions_json, content)
 
     def test_get_v10_images_path(self):
@@ -251,7 +282,7 @@ class TestApiPaths(functional.FunctionalTest):
         path = 'http://%s:%d/v1.a/images' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
 
     def test_get_v1a_images_path(self):
         """Assert GET /v1.a/images with no Accept: header
@@ -260,7 +291,7 @@ class TestApiPaths(functional.FunctionalTest):
         path = 'http://%s:%d/v1.a/images' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
 
     def test_get_va1_images_path(self):
         """Assert GET /va.1/images with no Accept: header
@@ -269,7 +300,7 @@ class TestApiPaths(functional.FunctionalTest):
         path = 'http://%s:%d/va.1/images' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
         self.assertEqual(self.versions_json, content)
 
     def test_get_versions_path(self):
@@ -279,7 +310,7 @@ class TestApiPaths(functional.FunctionalTest):
         path = 'http://%s:%d/versions' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual(self.versions_json, content)
 
     def test_get_versions_path_with_openstack_header(self):
@@ -291,7 +322,7 @@ class TestApiPaths(functional.FunctionalTest):
         http = httplib2.Http()
         headers = {'Accept': 'application/vnd.openstack.images-v1'}
         response, content = http.request(path, 'GET', headers=headers)
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual(self.versions_json, content)
 
     def test_get_v1_versions_path(self):
@@ -301,14 +332,14 @@ class TestApiPaths(functional.FunctionalTest):
         path = 'http://%s:%d/v1/versions' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(404, response.status)
+        self.assertEqual(http_client.NOT_FOUND, response.status)
 
     def test_get_versions_choices(self):
         """Verify version choices returned"""
         path = 'http://%s:%d/v10' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
         self.assertEqual(self.versions_json, content)
 
     def test_get_images_path_with_openstack_v2_header(self):
@@ -321,7 +352,7 @@ class TestApiPaths(functional.FunctionalTest):
         http = httplib2.Http()
         headers = {'Accept': 'application/vnd.openstack.images-v10'}
         response, content = http.request(path, 'GET', headers=headers)
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
         self.assertEqual(self.versions_json, content)
 
     def test_get_v12_images_path(self):
@@ -331,5 +362,5 @@ class TestApiPaths(functional.FunctionalTest):
         path = 'http://%s:%d/v1.2/images' % ('127.0.0.1', self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(300, response.status)
+        self.assertEqual(http_client.MULTIPLE_CHOICES, response.status)
         self.assertEqual(self.versions_json, content)
