@@ -21,7 +21,6 @@ from oslo_db import options
 
 import glance.common.client
 from glance.common import config
-from glance.db import migration
 import glance.db.sqlalchemy.api
 import glance.registry.client.v1.client
 from glance import tests as glance_tests
@@ -171,7 +170,7 @@ class ApiTest(test_utils.BaseTestCase):
             test_utils.execute('cp %s %s/tests.sqlite'
                                % (db_location, self.test_dir))
         else:
-            migration.db_sync()
+            test_utils.db_sync()
 
             # copy the clean db to a temp location so that it
             # can be reused for future tests
