@@ -15,6 +15,7 @@
 
 from oslo_config import cfg
 from oslo_serialization import jsonutils
+from six.moves import http_client
 # NOTE(jokke): simplified transition to py3, behaves like py2 xrange
 from six.moves import range
 
@@ -43,7 +44,7 @@ class TestPropertyQuotaViolations(base.ApiTest):
     def _get(self, image_id=""):
         path = ('/v2/images/%s' % image_id).rstrip('/')
         rsp, content = self.http.request(path, 'GET', headers=self._headers())
-        self.assertEqual(200, rsp.status)
+        self.assertEqual(http_client.OK, rsp.status)
         content = jsonutils.loads(content)
         return content
 
@@ -52,7 +53,7 @@ class TestPropertyQuotaViolations(base.ApiTest):
         headers = self._headers({'content-type': 'application/json'})
         rsp, content = self.http.request(path, 'POST', headers=headers,
                                          body=jsonutils.dumps(body))
-        self.assertEqual(201, rsp.status)
+        self.assertEqual(http_client.CREATED, rsp.status)
         return jsonutils.loads(content)
 
     def _patch(self, image_id, body, expected_status):
@@ -91,15 +92,17 @@ class TestPropertyQuotaViolations(base.ApiTest):
         self.config(image_property_quota=2)
 
         patch_body = [{'op': 'replace', 'path': '/k_4', 'value': 'v_4.new'}]
-        image = jsonutils.loads(self._patch(image_id, patch_body, 200))
+        image = jsonutils.loads(self._patch(image_id, patch_body,
+                                            http_client.OK))
         self.assertEqual('v_4.new', image['k_4'])
 
         patch_body = [{'op': 'remove', 'path': '/k_7'}]
-        image = jsonutils.loads(self._patch(image_id, patch_body, 200))
+        image = jsonutils.loads(self._patch(image_id, patch_body,
+                                            http_client.OK))
         self.assertNotIn('k_7', image)
 
         patch_body = [{'op': 'add', 'path': '/k_100', 'value': 'v_100'}]
-        self._patch(image_id, patch_body, 413)
+        self._patch(image_id, patch_body, http_client.REQUEST_ENTITY_TOO_LARGE)
         image = self._get(image_id)
         self.assertNotIn('k_100', image)
 
@@ -107,7 +110,7 @@ class TestPropertyQuotaViolations(base.ApiTest):
             {'op': 'remove', 'path': '/k_5'},
             {'op': 'add', 'path': '/k_100', 'value': 'v_100'},
         ]
-        self._patch(image_id, patch_body, 413)
+        self._patch(image_id, patch_body, http_client.REQUEST_ENTITY_TOO_LARGE)
         image = self._get(image_id)
         self.assertNotIn('k_100', image)
         self.assertIn('k_5', image)
@@ -119,7 +122,8 @@ class TestPropertyQuotaViolations(base.ApiTest):
                       {'op': 'add', 'path': '/k_99', 'value': 'v_99'}]
         to_rm = ['k_%d' % i for i in range(orig_property_quota) if i != 7]
         patch_body.extend([{'op': 'remove', 'path': '/%s' % k} for k in to_rm])
-        image = jsonutils.loads(self._patch(image_id, patch_body, 200))
+        image = jsonutils.loads(self._patch(image_id, patch_body,
+                                            http_client.OK))
         self.assertEqual('v_99', image['k_99'])
         self.assertEqual('v_100', image['k_100'])
         for k in to_rm:
